==> vtwm_5.4.7.orig.tar.gz: vtwm-5.4.7/version.c <==
/*****************************************************************************/
/**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
/**                          Salt Lake City, Utah                           **/
/**  Portions Copyright 1989 by the Massachusetts Institute of Technology   **/
/**                        Cambridge, Massachusetts                         **/
/**                                                                         **/
/**                           All Rights Reserved                           **/
/**                                                                         **/
/**    Permission to use, copy, modify, and distribute this software and    **/
/**    its documentation  for  any  purpose  and  without  fee is hereby    **/
/**    granted, provided that the above copyright notice appear  in  all    **/
/**    copies and that both  that  copyright  notice  and  this  permis-    **/
/**    sion  notice appear in supporting  documentation,  and  that  the    **/
/**    names of Evans & Sutherland and M.I.T. not be used in advertising    **/
/**    in publicity pertaining to distribution of the  software  without    **/
/**    specific, written prior permission.                                  **/
/**                                                                         **/
/**    EVANS & SUTHERLAND AND M.I.T. DISCLAIM ALL WARRANTIES WITH REGARD    **/
/**    TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES  OF  MERCHANT-    **/
/**    ABILITY  AND  FITNESS,  IN  NO  EVENT SHALL EVANS & SUTHERLAND OR    **/
/**    M.I.T. BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL  DAM-    **/
/**    AGES OR  ANY DAMAGES WHATSOEVER  RESULTING FROM LOSS OF USE, DATA    **/
/**    OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER    **/
/**    TORTIOUS ACTION, ARISING OUT OF OR IN  CONNECTION  WITH  THE  USE    **/
/**    OR PERFORMANCE OF THIS SOFTWARE.                                     **/
/*****************************************************************************/

/* djhjr - 4/23/96
char *Version = "Virtual Desktop TWM (VTWM) - R5 Release (5.3)";
*/
/* djhjr - 9/10/96
char *Version = "Virtual Desktop TWM (VTWM) - R5 Release 5.4";
*/
/* djhjr - 3/12/97
char *Version = "Virtual Desktop TWM (VTWM) - R5 Release 5.4.1";
*/
/* djhjr - 11/17/97
char *Version = "Virtual Desktop TWM (VTWM) - R5 Release 5.4.2";
*/
/* djhjr - 1/1/98
char *Version = "Virtual Desktop TWM (VTWM) - R5 Release 5.4.3";
*/
/* djhjr - 2/5/98
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.4";
*/
/* djhjr - 3/14/98
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.4a";
*/
/* djhjr - 3/20/98
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.4b";
*/
/* djhjr - 8/11/98
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.4c";
*/
/* djhjr - 9/27/98
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.5";
*/
/* djhjr - 1/30/99
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.5a";
*/
/* djhjr - 11/8/01
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.6";
*/
/* djhjr - 10/1/04
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.6a";
*/
/* djhjr - 10/2/04
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.6b";
*/
char *Version = "Virtual Desktop TWM (VTWM) - X11R4-6 Release 5.4.7";

==> vtwm-5.5.0.tar.gz: vtwm-5.5.0/version.c <==
/*****************************************************************************/
/**       Copyright 1988 by Evans & Sutherland Computer Corporation,        **/
/**                          Salt Lake City, Utah                           **/
/**  Portions Copyright 1989 by the Massachusetts Institute of Technology   **/
/**                        Cambridge, Massachusetts                         **/
/**                                                                         **/
/**                           All Rights Reserved                           **/
/**                                                                         **/
/**    Permission to use, copy, modify, and distribute this software and    **/
/**    its documentation  for  any  purpose  and  without  fee is hereby    **/
/**    granted, provided that the above copyright notice appear  in  all    **/
/**    copies and that both  that  copyright  notice  and  this  permis-    **/
/**    sion  notice appear in supporting  documentation,  and  that  the    **/
/**    names of Evans & Sutherland and M.I.T. not be used in advertising    **/
/**    in publicity pertaining to distribution of the  software  without    **/
/**    specific, written prior permission.                                  **/
/**                                                                         **/
/**    EVANS & SUTHERLAND AND M.I.T. DISCLAIM ALL WARRANTIES WITH REGARD    **/
/**    TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES  OF  MERCHANT-    **/
/**    ABILITY  AND  FITNESS,  IN  NO  EVENT SHALL EVANS & SUTHERLAND OR    **/
/**    M.I.T. BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL  DAM-    **/
/**    AGES OR  ANY DAMAGES WHATSOEVER  RESULTING FROM LOSS OF USE, DATA    **/
/**    OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER    **/
/**    TORTIOUS ACTION, ARISING OUT OF OR IN  CONNECTION  WITH  THE  USE    **/
/**    OR PERFORMANCE OF THIS SOFTWARE.                                     **/
/*****************************************************************************/

char *Version = "Virtual Desktop TWM (VTWM) - Release 5.5.0";


/*
  Local Variables:
  mode:c
  c-file-style:"GNU"
  c-file-offsets:((substatement-open 0)(brace-list-open 0)(c-hanging-comment-ender-p . nil)(c-hanging-comment-beginner-p . nil)(comment-start . "// ")(comment-end . "")(comment-column . 48))
  End:
*/
/* vim: sw=2
*/
